// Copyright Oryx Mail Systems GmbH. All enquiries to info@oryx.com, please.

#include "dict.h"

#include "allocator.h"


/*! \class Dict dict.h
  The Dict class provides a simple string-to-object dictionary.

  It is optimized for simplicity, and for extremely fast lookups when
  the number of items can be estimated in advance. Its other
  facilities are somewhat primitive. There is no iterator, for
  example, and no way to remove an object from the dictionary.

  An item can be added with insert(), retrieved with find() or the
  presence of an item can be tested with contains(). That's it.
*/


/*! \fn Dict::Dict()
    Creates an empty dictionary.
*/

/*! \fn T * Dict::find( const String &s ) const
    Looks for the object identified by \a s in the dictionary, and
    returns a pointer to it (or 0 if no such object was found).
*/

/*! \fn void Dict::insert( const String &s, T* r )
    Inserts the object \a r into the dictionary, identified by the
    string \a s.
*/

/*! \fn bool Dict::contains( const String &s ) const
    Returns true if an object identified by \a s exists in the
    dictionary, and false otherwise.
*/
