.\" Copyright Oryx Mail Systems GmbH. Enquiries to info@oryx.com, please.
.TH archiveopteryx.conf 5 2008-11-19 aox.org "Archiveopteryx Documentation"
.SH NAME
archiveopteryx.conf - configuration file for Archiveopteryx.
.SH SYNOPSIS
.B $CONFIGDIR/archiveopteryx.conf
.br
.SH DESCRIPTION
.nh
.PP
The
.I archiveopteryx.conf
file contains most global configuration settings for Archiveopteryx. It
is read by each server at startup. Syntax errors, unknown variables,
and other errors are logged via
.BR logd (8).
.PP
.I archiveopteryx.conf
and its sibling
.BR aoxsuper.conf (5)
are usually created at installation time, by running
.BR $LIBDIR/installer .
.PP
There is only one required variable, namely 
.IR db-password .
.SH "SECURITY NOTE"
Anyone who can read
.I archiveopteryx.conf
can see the database user password, and use this password to read all
mail and in many cases even delete mail.
.PP
By default,
.I archiveopteryx.conf
is readable only by root.
.SH SETTINGS
.PP
All settings share a common format:
.IP
name = value # comment
.PP
For the 
.I *-address
variables, the value may be either a hostname, an IPv4 or IPv6
address, the fully-qualified path to a Unix socket. For
.I imap-address
and a few other variables, the empty string is also allowed, meaning
"all IPv4/6 addresses of this host".
.SS "General Settings"
.IP hostname
Most of the servers need to know the fully-qualified hostname. The
default is computed at runtime and is normally acceptable.
.IP
Note that if the name is "localhost", there may be problems with
TLS. An IMAP/POP/SMTP/HTTP client may refuse a server certificate for
"localhost" if it already has seen a different certificate for
"localhost". We strongly suggest using a different
.IR hostname .
.IP use-ipv4
decides whether the various servers accept IPv4 connections.
.I true
by default.
.IP use-ipv6
decides whether the various servers accept IPv6 connections.
.I true
by default.
.IP undelete-time
is the number of days a message can be undeleted after being deleted,
.I 49
by default.
.IP server-processes
is the number of processes started to serve IMAP/POP/HTTP clients. This is
.I 1
by default. 1 is suitable for a small server.
.IP
The
.I server-processes
setting should be about as large as the number of CPUs available,
perhaps a little larger. We advise asking info@oryx.com in unusual
cases.
.SS "Database Access"
.IP db
The type of database. The default,
.IR postgres ,
is currently the only supported value.
.IP db-address
The address of the database server. The default is
.IR $DBADDRESS .
.IP db-port
The port number of the database server. The default is
.IR 5432 .
.IP db-name
The name of the database to use. The default is
.IR $DBNAME .
.IP db-schema
The name of the schema in the database where the database objects are
installed. The default is
.IR $DBSCHEMA .
It is safe to ignore this setting.
.IP db-user
The name of the unprivileged Postgres user that the servers ordinarily
use. The default is
.IR $AOXUSER .
.IP db-password
The database password used for the
.IR db-user .
The default is an empty string.
.IP
Unless a password is specified, Archiveopteryx sets up a randomly-chosen
password and writes it to the configuration file during installation.
.IP db-max-handles
The maximum number of database handles that Archiveopteryx may open. The
default is
.IR 4 .
.IP
The server creates one handle at startup, and may create others if the
load justifies it (and as controlled by
.IR db-handle-interval ).
Note, however, that when running with
.IR security=on ,
new database handles can be created only if you connect to the server
using TCP/IP, not via Unix sockets. In the latter case, the server must
use the first handle throughout its lifetime, since the socket is no
longer accessible after
.IR chroot .
.IP db-handle-interval
The minimum interval (in seconds) between the creation of new database
handles. The default is
.IR 120 .
.SS Logging
.IP log-address
The address of the log server. The default is
.IR 127.0.0.1 .
.IP log-port
The port number at which
.BR logd (8)
listens, and to which the other servers connect. The default is
.IR 2054 .
.IP logfile
tells
.BR logd (8)
where to write log events. It may be set to an absolute file name
(starting with '/'), or to "syslog/category" (e.g. "syslog/local2"),
which logs via
.BR syslog (2),
or to
.IR "-" ,
which causes everything to be logged to
.IR stdout .
The default is to log to
.IR $LOGFILE . 
.IP logfile-mode
is
.I $LOGFILEMODE
by default and controls the permissions used by
.BR logd (8)
if it creates
.IR logfile .
The format (three octal digits) is the same as that used by
.BR chmod (1).
.IP log-level
may be set to
.IR debug ,
.IR info ,
.IR significant ,
or
.IR error ,
in increasing order of severity (it is
.I significant
by default). If a message is logged with this severity or above, the log
server writes it to the logfile immediately. Messages with lower severity
are discarded.
.SS Security
.IP security
is
.I enabled
by default, and should be enabled whenever Archiveopteryx is
used in production. It causes the servers to lock themselves into a
.I chroot
jail and run with very limited unix and database privileges. Most
notably, they cannot open files or delete messages.
.IP
Turning security off has exactly one advantage: it simplifies
debugging.
.IP allow-plaintext-access
controls whether it is possible to read mail via an unencrypted
connection. The default value is
.IR always .
If this is changed to
.IR localhost ,
plaintext connections are permitted only from the host itself.
If it is changed to
.IR never ,
TLS is necessary to read mail.
.IP jail-directory
is
.I $JAILDIR
by default. On startup, each secure server uses
.BR chroot (2)
to jail themselves into this directory, which should be empty and
unreadable to
.IR jail-user .
.IP jail-user
is the user name under which the servers run, and is
.I $AOXUSER
by default. On startup, the servers change UID to this user. This user
should not have read or write access to the jail directory.
.IP jail-group
is the group name under which the servers run, and is
.I $AOXGROUP
by default. On startup, the servers change GID to this user.
.IP entropy-source
is the fully-qualified name of a file that acts as a source for random
bytes, whenever they are needed (e.g. SASL challenges). Set to
.I /dev/urandom
by default. If this is instead set to
.IR /dev/random ,
Archiveopteryx never uses anything less than perfectly random
numbers. In this case, make sure that there's enough entropy, or else
a series of rapid login attempts can block the entire server.
.SS "Cluster Configuration"
.IP start-ocd
controls whether the
.I ocd
server should be started by this instance of Archiveopteryx. It is
.I true
by default, but if you are running multiple instances of Archiveopteryx,
all but one instance should have it set to
.IR false ;
and the
.I ocd-address
and
.I ocd-port
should be set to the same values everywhere, so that all instances share
one
.IR ocd .
.IP ocd-address
The address where
.BR ocd (8)
listens for connections from other Archiveopteryx servers. The default is
.IR 127.0.0.1 .
.IP ocd-port
The port number at which
.BR ocd (8)
listens, and to which the other servers connect,
.I 2050
by default.
.IP ocadmin-address
The address where
.BR ocd (8)
listens for admin requests. The default is
.IR 127.0.0.1 .
.IP ocadmin-port
The port number at which
.BR ocd (8)
listens for admin requests.
.I 2051
by default.
.SS "User Authentication"
http://www.archiveopteryx.org/sasl describes SASL and
authentication in more detail.
.IP allow-plaintext-passwords
controls whether the servers permit plaintext passwords, and how such
passwords are handled.
May be set to
.I always
(which is the default) or
.IR never .
(Future versions of Archiveopteryx will offer more settings.)
.IP auth-digest-md5
controls whether the servers offer the digest-md5 SASL mechanism.
.I Disabled
by default due to interoperability problems.
.IP auth-cram-md5
controls whether the servers offer the cram-md5 SASL mechanism.
.I Enabled
by default.
.IP auth-plain
controls whether the servers offer the plain-text SASL
mechanism.
.I Enabled
by default.
.IP
Note that disabling auth-plain doesn't disable all plaintext
passwords, since SASL isn't always used. To disable plaintext
passwords, use the
.I allow-plaintext-passwords
variable above.
.IP auth-anonymous
controls whether the servers offer anonymous login,
.I disabled
by default.
.SS "Mail delivery"
.IP use-lmtp
controls whether
.BR archiveopteryx (8)
should accept mail via LMTP (RFC 2033). The default is
.IR enabled .
.IP lmtp-address
specifies the address where
.BR archiveopteryx (8)
should listen for LMTP connections, and to which
.BR deliver (8)
should connect. The default is
.IR 127.0.0.1 .
.IP lmtp-port
specifies which port
.BR archiveopteryx (8)
should listen to, and which port
.BR deliver (8)
should connect to. The default is
.IR 2026 .
.IP use-smtp
controls whether
.BR archiveopteryx (8)
should accept mail via SMTP/ESMTP (RFC 2821/1869). SMTP is
.I disabled
by default.
.IP smtp-address
specifies the address where
.BR archiveopteryx (8)
should listen for SMTP connections The default is an empty string,
which means all available IPv4 and IPv6 interfaces.
.IP smtp-port
specifies which port
.BR archiveopteryx (8)
should listen to. The default is
.IR 25 .
.IP use-subaddressing
controls whether messages addressed to
.I user+tag@example.org
are accepted for delivery to
.I user@example.org
(if the latter is a valid recipient address). The default is
.IR false .
.IP address-separator
is the character that separates the username from the subaddress in a
localpart, e.g. the
.I +
in
.IR user+tag@example.org .
The default, which you should not need to change, is
.IR + .
This setting is relevant only if
.I use-subaddressing
is true.
.IP soft-bounce
specifies whether a delivery problem causes a message to be rejected
permanently (soft-bounce disabled) or queued at the MTA (soft-bounce
enabled). This is
.I enabled
by default. We recommend disabling it when you are confident that mail
delivery works.
.IP message-copy
specifies whether or not to keep filesystem copies of incoming
messages, e.g. to burn a mail log to CD/DVD regularly.
The default value of
.I none
means that no copies are ever made.
.IP
Setting it to
.I delivered
keeps copies of all delivered messages, a value of
.I errors
keeps only those messages that could not be delivered because of errors, and
.I all
keeps copies of all messages.
.IP message-copy-directory
specifies a directory to which mail delivered via LMTP/SMTP is copied, if
.I message-copy
is set. Its default value is
.IR $MESSAGEDIR .
.IP
If
.I message-copy-directory
does not exist or is not writable,
Archiveopteryx logs an error at startup and exits.
.IP
Each file in
.I message-copy-directory
contains one or more header lines, namely
.BR Error ,
.B From
and
.BR To ,
then an empty line, then the verbatim received mail message. If there is an
.B Error
line, the message was not delivered, and the rest of the line
describes the problem.
.IP
The file's name is a unique string of numbers and hyphens. It ends with
"-err" if there was an error injecting the message into the database.
.SS "SMTP Submission"
.IP use-smtp-submit
controls whether
.BR archiveopteryx (8)
should accept mail via SMTP-Submit (RFC 4409). The default is
.IR enabled .
.IP check-sender-addresses
controls whether
.BR archiveopteryx (8)
should check whether the sender is authorised to use the addresses in
the message. From, Sender, Return-Path (SMTP Mail From) and Reply-To
are all checked. The default is
.IR disabled .
.IP submit-copy-to-sender
controls whether
.BR archiveopteryx (8)
should ensure that the sender receives a copy of outgoing mail. The default
is
.IR disabled .
This can be used to ensure that all outgoing mail is archived.
.IP
If the sender already receives a copy of the message, 
.I submit-copy-to-sender
has no effect. Senders will not receive two copies. The copy is
always sent to the user who sends the message, even if the From and/or
Return-Path is different. The sender's copy will be delivered through
the configured
.IR smarthost ,
as with any other outgoing message.
.IP smtp-submit-address
specifies the address where
.BR archiveopteryx (8)
should listen for Submit connections. The
default, an empty string, means to listen on all available IPv4 and
IPv6 addresses.
.IR 127.0.0.1 .
.IP smtp-submit-port
specifies which port
.BR archiveopteryx (8)
should listen to. The default is
.IR 587 .
.IP smarthost-address
specifies the address of the SMTP server which is used to relay mail to
remote recipients. The default is
.IR 127.0.0.1 .
.IP smarthost-port
specifies the port to use when forwarding mail to a smarthost. The
default is
.IR 25 .
(These defaults thus conflict with the default values of
.I smtp-address
and
.I smtp-port
when
.I use-smtp
is enabled.)
.IP use-smtps
controls whether
.BR archiveopteryx (8)
should accept SSL-wrapped SMTP connections. The default is
.IR false 
(and the use of STARTTLS with SMTP Submit is strongly recommended
instead).
.IP smtps-address
is the address where
.BR archiveopteryx (8)
listens for new SSL-wrapped SMTP connections. As for
.IR smtp-address ,
the default is an empty string, which means all available IPv4 and
IPv6 addresses.
.IP smtps-port
is the port where
.BR archiveopteryx (8)
accepts SSL-wrapped SMTP connections,
.I 465
by default.
.SS IMAP
.IP use-imap
must be enabled for
.BR archiveopteryx (8)
to accept IMAP connections. The default is
.IR true .
.IP imap-address
is the address where
.BR archiveopteryx (8)
listens for new connections. The
default, an empty string, means to listen on all available IPv4 and
IPv6 addresses.
.IP imap-port
is the port where 
.BR archiveopteryx (8)
accepts connections,
.I 143
by default.
.IP use-imaps
controls whether
.BR archiveopteryx (8)
should also accept SSL-wrapped IMAP connections. The default is
.I false
(and the use of STARTTLS over the standard IMAP port is strongly
recommended instead).
.IP imaps-address
is the address where
.BR archiveopteryx (8)
listens for new SSL-wrapped connections. As for
.IR imap-address ,
the default is an empty string, which means all available IPv4 and
IPv6 addresses.
.IP imaps-port
is the port where
.BR archiveopteryx (8)
accepts SSL-wrapped connections,
.I 993
by default.
.SS POP
.IP use-pop
must be enabled for
.BR archiveopteryx (8)
to accept POP3 connections. The default is
.IR false .
.IP pop-address
is the address where
.BR archiveopteryx (8)
listens for new connections. The default, an empty string, means to
listen on all available IPv4 and IPv6 addresses.
.IP pop-port
is the port where
.BR archiveopteryx (8)
accepts connections,
.I 110
by default.
.SS HTTP
.IP use-http
decides whether Archiveopteryx offers HTTP service at all, and is
.I no
by default.
.IP http-address
is the address where
.BR archiveopteryx (8)
listens for new connections. The default is
.IR 127.0.0.1 .
.IP http-port
is the port where
.BR archiveopteryx (8)
accepts connections,
.I 8808
by default.
.IP use-https
decides whether Archiveopteryx offers HTTPS (SSL-wrapped HTTP) service,
and is
.I no
by default.
.IP https-address
is the address where
.BR archiveopteryx (8)
listens for new HTTPS connections. The default is
.IR 127.0.0.1 .
.IP https-port
is the port where
.BR archiveopteryx (8)
accepts connections,
.I 8443
by default.
.IP accept-any-http-host
decides whether
.BR archiveopteryx (8)
accepts any hostname supplied by the client, and is
.I enabled
by default. Properly speaking, it would be better to disable this, but
that would add complexity without giving anything in return.
.IP use-web-archive
decides whether archiveopteryx provides web-visible archives of
world-readable mailboxes. The default is
.I false
and for the moment we recommend leaving it at false. This code is not
ready for production use.
.IP archive-prefix
is the common prefix for all URLs offering archive access to mailboxes
via the web. These mailboxes must be readable by the anonymous user.
The default value is empty.
.IP use-webmail
ldecides whether archiveopteryx provides webmail access. The default is
.I false
and we strongly recommend leaving it at false. Don't enable this.
.IP webmail-prefix
is the common prefix for all URLs offering authenticated webmail access
to mailboxes via the web. The default value is
.IR /webmail .
.IP webmail-css-url
points to the style sheet used for webmail and archive pages.
The default value is
.IR http://www.archiveopteryx.org/webmail/default.css .
By using a different URL you can change the appearance of the pages
completely.
.IP webmail-js-url
points to a javascript which will be included in all webmail and
archive pages. The default is an empty string, which means to not
include any external javascript. This can be used together with
.I webmail-css-url
to change the behaviour of the webmail and archive pages.
.IP favicon-url
is the URL of the favicon displayed for your site by many web browsers.
The default value is
.IR http://www.archiveopteryx.org/favicon.ico ,
but you can change it to anything. When the browser requests the favicon, 
.BR archiveopteryx (8)
responds with a redirect to this URL.
.SS SIEVE
.IP use-sieve
controls whether or not the
.I managesieve
server is started. The default is
.IR enabled .
.IP managesieve-address
specifies the address where
.BR archiveopteryx (8)
should listen for connections. The default is an empty string, which
means to listen on all available IPv4 and IPv6 addresses.
.IR an empt
.IP managesieve-port
specifies which port
.BR archiveopteryx (8)
should listen to. The default is
.IR 2000 .
.SS TLS
.IP use-tls
regulates whether Archiveopteryx supports TLS at all. The default is
.IR enabled .
.IP tls-certificate
is the absolute file name of the TLS private key and signed certificate,
e.g.
.IR $CONFIGDIR/imap.p15 .
If
.I tls-certificate
is not specified, tlsproxy generates a private key and a self-signed
certificate at runtime and stores both in
.IR $CONFIGDIR/automatic-key.p15 .
.IP tls-certificate-label
is a label that uniquely identifies the key and certificate to use in
the PKCS #15 key file identified by
.I tls-certificate
(which can contain multiple key pairs). By default, this
is empty, and the current hostname is used as a label.
.IP tls-certificate-secret
is a secret password used to access the appropriate key and certificate
in the PKCS #15 key file identified by
.IR tls-certificate .
.IP tlsproxy-address
is the address where
.BR tlsproxy (8)
listens for new connections. The default is
.IR 127.0.0.1 .
.IP tlsproxy-port
is the port where
.BR tlsproxy (8)
accepts connections,
.I 2061
by default.
.SH SYNTAX
.PP
The name is case insensitive, as shown:
.IP
hostname = test1.example.com
.br
HOSTNAME = mailserver.example.org
.PP
The value is case insensitive wherever possible. (Exceptions
include logfile, db-user and db-password.)
.PP
There are three datatypes: Strings, numbers and toggles.
.PP
Strings may be written as a single unquoted word or quoted with either
single or double quotes, as shown in these three examples:
.IP
db-password = single.word
.br
db-password = "rock'n'roll" # a 12-character password
.br
db-password = 'two words, quoted' # a 17-character one
.PP
Only single-line strings can be used. Single-word strings may contain
the characters a-z, A-Z, 0-9, dot, hyphen and slash.
.PP
Numbers are integers not smaller than 0 and not larger than 2147483647
(ie. 31-bit unsigned integers).
.PP
Toggles are written as a single word.
.IR Yes ,
.IR true ,
.IR on ,
.IR 1 ,
and
.I enabled
all
mean that the toggle is enabled, while
.IR no ,
.IR false ,
.IR off ,
.IR 0 ,
and
.I disabled
unsurprisingly mean disabled. Toggles are case-insensitive.
.IP
use-lmtp = yes
.br
crash-and-delete-all-the-mail = off
.PP
Spaces are allowed at the start of the line, before and after '=', and
after the value. Comments extend from '#' to the end of the line.
.IP
# this is a comment
.br
hostname=stuff.nonsense.example.com # also a comment
.br
 logfile    =   /dev/null# and this is a comment
.br
# empty lines are ignored
.SH AUTHOR
The Archiveopteryx developers, info@oryx.com.
.SH VERSION
This man page covers Archiveopteryx version 3.0.4, released 2008-11-19,
http://www.archiveopteryx.org/3.0.4
.SH SEE ALSO
.BR archiveopteryx (8),
.BR deliver (8),
.BR logd (8),
.BR ocd (8),
.BR tlsproxy (8),
.BR oryx (7),
http://www.archiveopteryx.org
